package com.ghy.system.mapper;

import com.ghy.system.domain.SysArea;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * @author clunt
 * 区域表Mapper层
 */
public interface SysAreaMapper {

    /**
     * @param sysArea 筛选条件
     * @return 返回结果
     */
    public List<SysArea> selectSysAreaList(SysArea sysArea);

    /**
     * @param areaId 区域id
     * @return 区域实体
     */
    public SysArea selectById(Long areaId);

    /**
     * @param areaCode 区域编码
     * @return 区域实体
     */
    public SysArea selectByAreaCode(String areaCode);

    /**
     * @param areaId id数组
     * @return 删除成功条数
     */
    public int deleteSysAreaByIds(Long [] areaId);

    /**
     * @param sysArea 更新内容
     * @return 成功条数
     */
    public int updateSysArea(SysArea sysArea);

    /**
     * @param sysArea 新增区域实体
     * @return 成功条数
     */
    public int insertSysArea(SysArea sysArea);

    /**
     * @param sysArea 区域
     * @return 区域实体
     */
    public SysArea selectByName(SysArea sysArea);

}
